@@ -1,6 +1,8 @@
-import time, pyperclip
+import time, pyperclip, os, darkdetect, threading
 from kivy import Config
-import os, darkdetect, threading
+from kivy.uix.boxlayout import BoxLayout
+from kivymd.uix.button import MDFlatButton
+from kivymd.uix.dialog import MDDialog
 
 Config.set('graphics', 'resizable', 0)
 Config.set('input', 'mouse', 'mouse, multitouch_on_demand')
@@ -15,6 +17,10 @@ from screeninfo import get_monitors
 from kivy.properties import *
 
 
+class Content(BoxLayout):
+    pass
+
+
 def icons(f: str = ''):
     from kivymd.icon_definitions import md_icons
     print([x for x in list(md_icons.keys()) if f in x])
@@ -106,7 +112,11 @@ class Kivy4(MDApp):
             minimum = [0.1, 0.1]
 
         self.app_name = app_name
-        self.builder_string = ''
+        self.builder_string = '''<Content>
+    orientation: "vertical"
+    spacing: "12dp"
+    size_hint_y: None
+    height: "100dp"'''
 
         if app_data:
             app_data_path = os.getenv('APPDATA') + '/' + app_name
@@ -117,6 +127,7 @@ class Kivy4(MDApp):
             self.sun_icon = sun_icon
             self.isDarkMode()
 
+        self.dialog = None
         self.setProperties(main_color, icon, toolbar, string, pre_string)
         self.disable_x = disable_x
 
@@ -406,4 +417,40 @@ Screen:
         date_dialog.open()
 
     def on_cancel_picker(self, instance, value):
-        pass
\ No newline at end of file
+        pass
+
+    def popup(self, title='My popup', content=Content(), cancel_text='CANCEL', okay_text='OKAY',
+              okay_func=lambda: print('yes'), cancel_func=None):
+
+        if cancel_func is None:
+            cancel_func = lambda *args: self.dismiss()
+
+        if not self.dialog:
+            self.dialog = MDDialog(
+                title=title,
+                type="custom",
+                content_cls=content,
+                buttons=[
+                    MDFlatButton(
+                        text=cancel_text,
+                        theme_text_color="Custom",
+                        text_color=self.theme_cls.primary_color,
+                        on_press=cancel_func
+                    ),
+                    MDFlatButton(
+                        text=okay_text,
+                        theme_text_color="Custom",
+                        text_color=self.theme_cls.primary_color,
+                        on_press=okay_func
+                    ),
+                ],
+            )
+
+        self.dialog.open()
+
+    def dismiss(self):
+        try:
+            self.dialog.dismiss()
+
+        except Exception as e:
+            print(e)
